@@ -1,11 +1,12 @@
 #!/bin/bash
-set -eu
+
+set -euxo pipefail
 
 . $(dirname $0)/install-deps.sh
 # NOTE(pas-ha) the above exports some useful variables like
 # $PYTHON , $PIP and $VENV depending on venv install or not
 
-DEFAULT_PIP_ANSIBLE='>=2.9,<2.10'
+DEFAULT_PIP_ANSIBLE='>=2.9,<2.11'
 
 ANSIBLE_COLLECTIONS_REQ=${ANSIBLE_COLLECTIONS_REQ:-$(dirname $0)/../ansible-collections-requirements.yml}
 ANSIBLE_COLLECTION_SOURCE_PATH=
